@@ -2,9 +2,13 @@
 
 source 'https://rubygems.org'
 
-# Specify your gem's dependencies in async-io.gemspec
 gemspec
 
+group :maintenance, optional: true do
+	gem "bake-modernize"
+	gem "bake-bundler"
+end
+
 group :test do
 	gem 'benchmark-ips'
 	gem 'ruby-prof', platforms: :mri
